@@ -17,20 +17,51 @@ sub new {
     return $self;
 }
 
+sub abstract {
+    return 'Class to compute Iridium Classic flares';
+}
+
+sub add_to_cleanup {
+    return [ qw{ cover_db } ];
+}
+
+sub author {
+    return 'Tom Wyant (wyant at cpan dot org)';
+}
+
 sub build_requires {
     return +{
-	'Config'	=> 0,
-	'Data::Dumper'	=> 0,
-	'Exporter'	=> 5.64,
+	'Safe'		=> 0,
 	'Test::More'	=> 0.88,	# Because of done_testing().
+	'Time::Local'	=> 0,
+	lib		=> 0,
     };
 }
 
+sub configure_requires {
+    return +{
+	'Exporter'	=> 5.64,
+	'FileHandle'	=> 0,
+	'Getopt::Std'	=> 0,
+	'lib'	=> 0,
+	'strict'	=> 0,
+	'warnings'	=> 0,
+    };
+}
+
+sub dist_name {
+    return 'Astro-Coord-ECI-TLE-Iridium';
+}
+
 sub distribution {
     my ( $self ) = @_;
     return $self->{distribution};
 }
 
+sub license {
+    return 'perl';
+}
+
 sub meta_merge {
     my ( undef, @extra ) = @_;
     return {
@@ -38,13 +69,11 @@ sub meta_merge {
 	    version	=> 2,
 	},
 	dynamic_config	=> 1,
-	no_index	=> {
-	    directory	=> [ qw{ inc t xt } ],
-	},
 	resources	=> {
 	    bugtracker	=> {
-		web	=> 'https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-satpass',
-                mailto  => 'wyant@cpan.org',
+		web	=> 'https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-Coord-ECI-TLE-Iridium',
+		# web	=> 'https://github.com/trwyant/perl-Astro-Coord-ECI-TLE-Iridium/issues',
+		mailto  => 'wyant@cpan.org',
 	    },
 	    license	=> 'http://dev.perl.org/licenses/',
 	    repository	=> {
@@ -57,6 +86,20 @@ sub meta_merge {
     };
 }
 
+sub module_name {
+    return 'Astro::Coord::ECI::TLE::Iridium';
+}
+
+sub no_index {
+    return +{
+      directory => [
+                     'inc',
+                     't',
+                     'xt',
+                   ],
+    };
+}
+
 sub provides {
     -d 'lib'
 	or return;
@@ -73,15 +116,15 @@ sub requires {
 ##  if ( ! $self->distribution() ) {
 ##  }
     return +{
+	'Astro::Coord::ECI'		=> 0.091,
 	'Astro::Coord::ECI::TLE'	=> 0.091,
 	'Astro::Coord::ECI::Utils'	=> 0.091,
 	'Carp'		=> 0,
 	'POSIX'		=> 0,
-	'Scalar::Util'	=> 0,
-	'base'		=> 0,
-	'constant'	=> 0,
-	'strict'	=> 0,
-	'warnings'	=> 0,
+	base		=> 0,
+	constant	=> 0,
+	strict		=> 0,
+	warnings	=> 0,
 	@extra,
     };
 }
@@ -90,6 +133,14 @@ sub requires_perl {
     return 5.006002;
 }
 
+sub script_files {
+    return [
+    ];
+}
+
+sub version_from {
+    return 'lib/Astro/Coord/ECI/TLE/Iridium.pm';
+}
 
 1;
 
@@ -125,6 +176,19 @@ This class supports the following public methods:
 
 This method instantiates the class.
 
+=head2 abstract
+
+This method returns the distribution's abstract.
+
+=head2 add_to_cleanup
+
+This method returns a reference to an array of files to be added to the
+cleanup.
+
+=head2 author
+
+This method returns the name of the distribution author
+
 =head2 build_requires
 
  use YAML;
@@ -135,6 +199,20 @@ modules required to build the C<Astro-Coord-ECI-TLE-Iridium> package,
 suitable for use in a F<Build.PL> C<build_requires> key, or a
 F<Makefile.PL> C<< {META_MERGE}->{build_requires} >> key.
 
+=head2 configure_requires
+
+ use YAML;
+ print Dump( $meta->configure_requires() );
+
+This method returns a reference to a hash describing the modules
+required to configure the package, suitable for use in a F<Build.PL>
+C<configure_requires> key, or a F<Makefile.PL>
+C<< {META_MERGE}->{configure_requires} >> or C<CONFIGURE_REQUIRES> key.
+
+=head2 dist_name
+
+This method returns the distribution name.
+
 =head2 distribution
 
  if ( $meta->distribution() ) {
@@ -146,6 +224,10 @@ F<Makefile.PL> C<< {META_MERGE}->{build_requires} >> key.
 This method returns the value of the environment variable
 C<MAKING_MODULE_DISTRIBUTION> at the time the object was instantiated.
 
+=head2 license
+
+This method returns the distribution's license.
+
 =head2 meta_merge
 
  use YAML;
@@ -153,11 +235,21 @@ C<MAKING_MODULE_DISTRIBUTION> at the time the object was instantiated.
 
 This method returns a reference to a hash describing the meta-data which
 has to be provided by making use of the builder's C<meta_merge>
-functionality. This includes the C<dynamic_config>, C<no_index> and
-C<resources> data.
+functionality. This includes the C<dynamic_config> and C<resources>
+data.
 
 Any arguments will be appended to the generated array.
 
+=head2 module_name
+
+This method returns the name of the module the distribution is based
+on.
+
+=head2 no_index
+
+This method returns the names of things which are not to be indexed
+by CPAN.
+
 =head2 provides
 
  use YAML;
@@ -187,11 +279,20 @@ may be added.
 
 This method returns the version of Perl required by the package.
 
+=head2 script_files
+
+This method returns a reference to an array containing the names of
+script files provided by this distribution. This array may be empty.
+
+=head2 version_from
+
+This method returns the name of the distribution file from which the
+distribution's version is to be derived.
+
 =head1 ATTRIBUTES
 
 This class has no public attributes.
 
-
 =head1 ENVIRONMENT
 
 =head2 MAKING_MODULE_DISTRIBUTION
@@ -200,11 +301,12 @@ This environment variable should be set to a true value if you are
 making a distribution. This ensures that no configuration-specific
 information makes it into F<META.yml>.
 
-
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-Coord-ECI-TLE-Iridium>,
+L<https://github.com/trwyant/perl-Astro-Coord-ECI-TLE-Iridium/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -212,7 +314,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2020 by Thomas R. Wyant, III
+Copyright (C) 2010-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
