@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.129';
+our $VERSION = '0.130';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -196,7 +196,6 @@ my %statatr = (		# for convenience of get() and put().
 
 __PACKAGE__->alias (iridium => __PACKAGE__);
 
-
 #	Pre-compute the transform vectors for each of the three Main
 #	Mission Antennae, so that we do not have to repeatedly compute
 #	the sin and cos of the relevant angles. The transform we are
@@ -224,7 +223,6 @@ __PACKAGE__->alias (iridium => __PACKAGE__);
 #	  | -cos(theta) * sin(phi)   sin(theta) * sin(phi)  cos(phi) |
 #	  +-                                                        -+
 
-
 my @transform_vector;
 {	# Begin local symbol block.
 my $cosphi = cos (MMAPHI);
@@ -243,7 +241,6 @@ foreach my $mma (0 .. 2) {
     }
 }	# End local symbol block.
 
-
 #	We also pre-compute the inverse transforms, to facilitate the
 #	recovery of the virtual image of the illuminating body.
 
@@ -291,10 +288,8 @@ EOD
     }
 }
 
-
 #	see Astro::Coord::ECI->attribute ();
 
-
 sub attribute {
     my ($self, $name) = @_;
     return exists $accessor{$name} ?
@@ -302,7 +297,6 @@ sub attribute {
 	$self->SUPER::attribute ($name);
 }
 
-
 =item $tle->before_reblessing ()
 
 This method supports reblessing into a subclass. It is intended to do
@@ -320,7 +314,6 @@ sub before_reblessing {
     return;
 }
 
-
 =item $tle->can_flare ($spare);
 
 This method returns true (in the Perl sense) if the object is capable
@@ -340,7 +333,6 @@ sub can_flare {
     return !$status || $spare && $status == $self->BODY_STATUS_IS_SPARE;
 }
 
-
 =item @flares = $tle->flare ($sta, $start, $end);
 
 This method returns the list of flares produced by the given Iridium
@@ -557,7 +549,6 @@ eod
     my $night_limit = $twilight + DAY_TOLERANCE;
     my $illum_tolerance = deg2rad (15);
 
-
 #	We assume our observing location is fixed on the surface of the
 #	Earth, and take advantage of the fact that an Iridium orbit is
 #	very nearly polar. We use these to calculate the intervals
@@ -603,20 +594,17 @@ eod
 	$self->universal ($time);
 	my ($satlat, $satlon, $satalt) = $self->geodetic;
 
-
 #	Correct time to put satellite at same latitude as station.
 
 	$time += ($asc ? $stalat - $satlat : $satlat - $stalat)
 	    / $angular_velocity;
 	($satlat, $satlon, $satalt) = $self->universal ($time)->geodetic;
 
-
 #	Calculate whether satellite is above horizon.
 
 	my ( undef, $elev, $rng ) = $station->azel_offset( $self, 0 );
 	$elev > $horizon or next;
 
-
 #	Check whether we are interested in this potential flare, based
 #	on whether it might be during the day, or am, or pm.
 
@@ -634,14 +622,12 @@ eod
 	    0;
 	    } || next);
 
-
 #	Calculate whether the satellite is illuminated.
 
 ##	my $lit = ($self->azel ($illum->universal ($time)))[1] >=
 	($self->azel ($illum->universal ($time)))[1] >=
 	    $self->dip () - $illum_tolerance or next;
 
-
 #	For our screening to work we need to know the maximum angular
 #	distance we can travel in 30 seconds. This is the arc tangent
 #	of the velocity over the range
@@ -652,7 +638,6 @@ eod
 	    * 30;
 	$max_angle += $max_mirror_angle;	# Take into account near misses.
 
-
 #	Iterate over a period of 16 minutes centered on our current
 #	time, calculating the location of the reflection of the sun
 #	versus the satellite, as seen by the observer.
@@ -661,7 +646,6 @@ eod
 	foreach my $deltat (-8 .. 8) {
 	    my $time = $deltat * 60 + $time;
 
-
 #	See if the satellite is illuminated at this time.
 #	TODO This code may need some slop; specifically we might want to
 #	assume the Sun is higher than it actually is by $max_angle.
@@ -669,7 +653,6 @@ eod
 	    ($self->universal ($time)->azel ($illum->universal ($time)))[1] >=
 		$self->dip () or next;
 
-
 #	Transform the relevant coordinates into a coordinate system
 #	in which the axis of the satellite is along the Z axis (with
 #	the Earth in the negative Z direction) and the direction of
@@ -681,13 +664,11 @@ eod
 		$self->_flare_transform_coords_list (
 		$illum, $station->universal( $time ) );
 
-
 #	Now we do a second iteration over the Main Mission Antennae,
 #	checking for the position of the Sun's reflection.
 
 	    foreach my $mma (0 .. 2) {
 
-
 #	We clone the sun and the station, and then calculate the angle
 #	between the satellite and the reflection of the Sun, as seen by
 #	the observer. We skip to the next antenna if no reflection is
@@ -699,31 +680,26 @@ eod
 		    my $angle = _flare_calculate_angle_list(
 		    $mma, $illum_vector, $station_vector ) );
 
-
 #	Save the angle, time, and cloned station for subsequent
 #	analysis.
 
 		push @{$flare_potential[$mma]},
 		    [$angle, $time, $illum_vector, $station_vector];
 
-
 #	End of iterating over Main Mission Antennae.
 
 	    }
 
-
 #	End of iterating over 16 minute period centered on current
 #	time.
 
 	}
 
-
 #	Now iterate over each MMA to calculate its flare, if any.
 
 MMA_LOOP:
 	foreach my $mma (0 .. 2) {
 
-
 #	Find the best possibility for a flare. If none, or the angle is
 #	more than the max possible, ignore this antenna.
 
@@ -760,7 +736,6 @@ MMA_LOOP:
 		    $flare_potential[$mma][$inx + 1]);
 	    };	# End local symbol block;
 
-
 #	Use successive approximation to find the time of minimum
 #	angle. We can not use a linear split-the-difference search,
 #	because the behavior is too far from linear. So we fudge by
@@ -771,7 +746,6 @@ MMA_LOOP:
 
 	    while (abs ($flare_approx[1][1] - $flare_approx[0][1]) > .1) {
 
-
 #	Calculate the next time to try as a weighted average of the
 #	previous two approximations, with the worse approximation
 #	having three times the weight of the better one. This prevents
@@ -785,7 +759,6 @@ MMA_LOOP:
 		my $time = ($flare_approx[1][1] * 3 + $flare_approx[0][1]) / 4;
 ####		my $time = ($flare_approx[1][1] * 6 + $flare_approx[0][1]) / 7;
 
-
 #	Transform the relevant coordinates into a coordinate system
 #	in which the axis of the satellite is along the Z axis (with
 #	the Earth in the negative Z direction) and the direction of
@@ -798,7 +771,6 @@ MMA_LOOP:
 			$illum->universal( $time ),
 			$station->universal( $time ) );
 
-
 #	Calculate the angle between the satellite and the reflection
 #	of the Sun, as seen by the observer.
 
@@ -806,30 +778,25 @@ MMA_LOOP:
 		    $mma, $illum_vector, $station_vector );
 		defined $angle or next MMA_LOOP;
 
-
 #	Store the data in our approximation list, in order by angle.
 
 		pop @flare_approx;
 		splice @flare_approx, $angle >= $flare_approx[0][0], 0,
 		    [$angle, $time, $illum_vector, $station_vector];
 
-
 #	End of successive approximation of time of minimum angle.
 
 	    }
 
-
 #	Pull the (potential) flare data off the approximation list.
 
 	    my ($angle, $time, $illum_vector, $station_vector) =
 		    @{$flare_approx[0]};
 
-
 #	Skip it if the mirror angle is greater than the max.
 
 	    next if $angle > $max_mirror_angle;
 
-
 #	All our approximations may have left us with a satellite which
 #	is not quite lit. This happened with Iridium 32 (OID 24945) on
 #	Feb 03 2007 at 07:45:19 PM. So we check for illumination one
@@ -842,7 +809,6 @@ MMA_LOOP:
 	    ($self->universal ($time)->azel ($illum->universal ($time)))[1] >=
 		$self->dip () or next;
 
-
 #	Calculate all the flare data.
 
 	    my $flare = $self->_flare_char_list ($station, $mma, $angle,
@@ -853,12 +819,10 @@ MMA_LOOP:
 	    push @flares, $flare
 		if !$flare->{status} && $want{$flare->{type}};
 
-
 #	End of iteration over each MMA to calculate its flare.
 
 	}
 
-
 #	Compute the next approxiate crossing of the observer's
 #	latitude.
 
@@ -871,7 +835,6 @@ MMA_LOOP:
 
 }
 
-
 #	[$angle, $time, $illum_vector, $station_vector] =
 #	    $self->_flare_entrance ($illum, $station, $mma, $start,
 #	    $end);
@@ -976,7 +939,6 @@ sub _flare_transform_coords_inverse_list {
     return @rslt;
 }
 
-
 #	$angle = _flare_calculate_angle_list($mma, $illum, $station)
 
 #	This private subroutine calculates the angle between the
@@ -1016,7 +978,6 @@ sub _flare_calculate_angle_list {
     return _list_angle( $station, $illum, [ 0, 0, 0 ] );
 }
 
-
 #	$hash_ref = $iridium->_flare_char_list (...)
 #
 #	Calculate the characteristics of the flare of the given body.
@@ -1044,13 +1005,11 @@ if ($elev < $horizon) {
 	'Satellite %.2f degrees below horizon', rad2deg ($horizon - $elev)));
     }
 
-
 #	Retrieve the illuminating body information.
 
 my $illum = $self->get ('illum');
 my $illum_radius = $illum->get ('diameter') / 2;
 
-
 #	Retrieve missing station information.
 
 my $height = ($station->geodetic)[2];
@@ -1061,7 +1020,6 @@ my $sun = $self->get( 'sun' );
 my $twilight = $self->get ('twilight');
 my $atm_extinct = $self->get ('extinction');
 
-
 #	Calculate the range to the satellite, and to the reflection of
 #	the Sun, from the observer.
 
@@ -1106,13 +1064,11 @@ my $central_mag = $central_magnitude + $area_correction;
 
 #	And for the test case, I got -8.0. Amazing.
 
-
 #	Calculate the atmospheric extinction of the flare.
 
 my $extinction = $atm_extinct ?
 	atmospheric_extinction ($elev, $height) : 0;
 
-
 #	The following off-axis magnitude calculation is the result of
 #	normalizing Ron Lee's magnitude data (made available by Randy
 #	John in various forms at http://home.comcast.net/~skysat/ ) for
@@ -1187,14 +1143,12 @@ my $flare_mag = $limb_darkening > 0 ? do {
 	$extinction;
     min ($specular_mag, $off_axis_mag) } : $off_axis_mag;
 
-
 #	Compute the flare type (am, day, or pm)
 
 my $sun_elev = ($station->azel ($sun->universal ($time)))[1];
 my $flare_type = $sun_elev >= $twilight ? 'day' :
 	( $self->_time_in_zone( $time ) )[2] > 12 ? 'pm' : 'am';
 
-
 #	Compute the angle from the Sun to the flare.
 
 my $sun_angle = $station->angle ($sun, $self);
@@ -1240,7 +1194,6 @@ my ($virtual_image, $image_vector) = do {
     ];
     $image_vector->[2] = - $image_vector->[2];
 
-
     # Undo the rotations that placed the MMA of interest in the X-Y
     # plane.
 
@@ -1249,7 +1202,6 @@ my ($virtual_image, $image_vector) = do {
 	    $inverse_transform_vector[$mma][$_] ) } 0 .. 2
     ];
 
-
     # Transform from satellite-local coordinates to ECI coordinates.
 
     ( $image_vector ) = $self->_flare_transform_coords_inverse_list(
@@ -1262,7 +1214,6 @@ my ($virtual_image, $image_vector) = do {
 	$image_vector );
     };
 
-
 #	Compute the distance to the flare center.
 
 #	For the calculation, consider the Earth flat, and consider the
@@ -1305,7 +1256,6 @@ my $sub_vector = do {
 my $sub_point = Astro::Coord::ECI->new(
     station => $station )->universal( $time )->eci( @$sub_vector );
 
-
 #	Stash the data.
 
 my %rslt = (
@@ -1336,7 +1286,6 @@ my %rslt = (
 return wantarray ? %rslt : \%rslt;
 }
 
-
 #	$ainv = _invert_matrix_list ($a)
 
 #	This subroutine takes a reference to a list of three list
@@ -1447,7 +1396,6 @@ sub magnitude {
     return $mag;
 }
 
-
 =item @data = $tle->reflection ($station, $time)
 
 This method returns a list of references to hashes containing the same
@@ -1482,7 +1430,6 @@ sub reflection {
     return $self->$method( $station, $time );
 }
 
-
 # Called as $self->$method, above
 sub _reflection_fixed {	## no critic (ProhibitUnusedPrivateSubroutines)
     my ( $self, $station, $time ) = @_;
@@ -1491,7 +1438,6 @@ sub _reflection_fixed {	## no critic (ProhibitUnusedPrivateSubroutines)
     my $debug = $self->get ('debug');
     my $illum = $self->get ('illum')->universal ($time);
 
-
 #	Calculate whether satellite is above horizon.
 
     my (undef, $elev) = $station->universal ($time)->
@@ -1500,7 +1446,6 @@ sub _reflection_fixed {	## no critic (ProhibitUnusedPrivateSubroutines)
 	sprintf ('Satellite %.2f degrees below horizon', rad2deg (-$elev)))
 	unless $elev >= 0;
 
-
 #	Calculate whether the satellite is illuminated.
 
     my $lit = ($self->azel ($illum->universal ($time)))[1] - $self->dip ();
@@ -1509,7 +1454,6 @@ sub _reflection_fixed {	## no critic (ProhibitUnusedPrivateSubroutines)
 	    rad2deg (-$lit)))
 	unless $lit >= 0;
 
-
 #	Transform the relevant coordinates into a coordinate system
 #	in which the axis of the satellite is along the Z axis (with
 #	the Earth in the negative Z direction) and the direction of
@@ -1544,7 +1488,6 @@ eod
     return wantarray ? @rslt : \@rslt;
 }
 
-
 =item $tle->set ($name => $value ...)
 
 This method sets the value of the given attribute (or attributes).
@@ -1632,7 +1575,6 @@ sub __parse_name {
     }
 }
 
-
 {
 
     my %status_map = (
@@ -1946,8 +1888,10 @@ effort.
 
 =head1 BUGS
 
-Bugs can be reported to the author by mail, or through
-L<https://github.com/trwyant/perl-Astro-Coord-ECI-TLE-Iridium/issues/>.
+Support is by the author. Please file bug reports at
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-Coord-ECI-TLE-Iridium>,
+L<https://github.com/trwyant/perl-Astro-Coord-ECI-TLE-Iridium/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
